/*
*********************************************************************
          
                   Bollinger Squeeze Advanced
                  Original code by Nick Bilak
                   Modifications by Akuma99
                   Copyright  2010 Akuma99
                  http://www.twitter.com/Akuma99
               
   Trigger types: 1-stochastic, 2-cci, 3-rsi, 4-macd, 5-momentum
                  6-williams, 7-adx, 8-demarker
                  
*********************************************************************
*/

#property copyright "Copyright  2010, Akuma99"
#property link      "http://www.twitter.com/Akuma99 "

#property indicator_separate_window
#property indicator_buffers 7
#property indicator_color1 Green
#property indicator_color2 IndianRed
#property indicator_color3 Blue
#property indicator_color4 Blue
#property indicator_color5 Red
#property indicator_color6 Gray
#property indicator_color7 Purple

int       bolPrd=20;
double    bolDev=2.0;
int       keltPrd=20;
double    keltFactor=1.5;

extern bool      showLine=false;
extern int       triggerType=3;
extern string    _="1-stoch, 2-cci, 3-rsi, 4-macd, 5-mom, 6-will, 7-adx, 8-demark";
extern int       stochPeriod_trigger1=8;
extern int       cciPeriod_trigger2=20;
extern int       rsiPeriod_trigger3=8;
extern int       macd_fastEMA_trigger4=12;
extern int       macd_slowEMA_trigger4=26;
extern int       macd_macdSMA_trigger4=9;
extern int       momentumPeriod_trigger5=14;
extern int       williamsPR_trigger6=24;
extern int       adx_trigger7=11;
extern int       demarker_trigger8=13;

double upB[];
double loB[];
double upB2[];
double loB2[];
double mm[];
double histoLine[];
double arrowBuffer[];
double cross[];

int counted_bars = 0;
int i,j,slippage=3;
double breakpoint=0.0;
double ema=0.0;
int peakf=0;
int peaks=0;
int valleyf=0;
int valleys=0, limit=0;
double ccis[61],ccif[61];
double delta=0;
double ugol=0;

int init() 
{
   IndicatorBuffers(7);
   
   SetIndexStyle(0,DRAW_HISTOGRAM,STYLE_SOLID,3,indicator_color1);
   SetIndexBuffer(0,upB);
   SetIndexEmptyValue(0,EMPTY_VALUE);
   
   SetIndexStyle(1,DRAW_HISTOGRAM,STYLE_SOLID,3,indicator_color2);
   SetIndexBuffer(1,loB);
   SetIndexEmptyValue(1,EMPTY_VALUE);

   SetIndexStyle(2,DRAW_HISTOGRAM,STYLE_SOLID,3,indicator_color3);
   SetIndexBuffer(2,upB2);
   SetIndexEmptyValue(2,EMPTY_VALUE);
   
   SetIndexStyle(3,DRAW_HISTOGRAM,STYLE_SOLID,3,indicator_color4);
   SetIndexBuffer(3,loB2);
   SetIndexEmptyValue(3,EMPTY_VALUE);
   
   SetIndexStyle(5,DRAW_LINE,0,1,indicator_color5);
   SetIndexBuffer(4,mm);
   
   SetIndexStyle(5,DRAW_LINE,0,1,indicator_color6);
   SetIndexBuffer(5,histoLine);
   
   SetIndexStyle(6,DRAW_HISTOGRAM,STYLE_SOLID,2,indicator_color7);
   SetIndexBuffer(6,cross);
   SetIndexEmptyValue(6,EMPTY_VALUE);
         
   return(0);
}

int deinit() 
{
   SetLevelValue(1,NULL);
   SetLevelValue(2,NULL);
   SetLevelValue(3,NULL);
   SetLevelValue(4,NULL);
   SetLevelValue(5,NULL);
   SetLevelValue(6,NULL);
   SetLevelValue(7,NULL);
}

int start() 
{
   double diff, d, std, bbs;
   
   if (counted_bars < 0) return(-1);
   
   if (counted_bars > 0) counted_bars--;
       
   int shift = (Bars - 31) - counted_bars;
   
   while (shift >= 0)
   {
      switch (triggerType) 
      {
         case 1:
         d=iStochastic(NULL,0,stochPeriod_trigger1,3,3,MODE_EMA,0,MODE_MAIN,shift)-50;
         IndicatorShortName("Bollinger Squeeze with Stochastic ("+stochPeriod_trigger1+",3,3)");
         break;
         case 2:
         d=iCCI(NULL,0,cciPeriod_trigger2,PRICE_CLOSE,shift);
         IndicatorShortName("Bollinger Squeeze with CCI ("+cciPeriod_trigger2+",CLOSE)");
         break;
         case 3:
         d=iRSI(NULL,0,rsiPeriod_trigger3,PRICE_CLOSE,shift)-50;
         IndicatorShortName("Bollinger Squeeze with RSI ("+rsiPeriod_trigger3+",CLOSE)");
         break;
         case 4:
         d=iMACD(NULL,0,12,26,9,PRICE_CLOSE,MODE_MAIN,shift);
         IndicatorShortName("Bollinger Squeeze with MACD & cross ("+macd_fastEMA_trigger4+","+macd_slowEMA_trigger4+","+macd_macdSMA_trigger4+")");
         mm[shift]=iMACD(NULL,0,macd_fastEMA_trigger4,macd_slowEMA_trigger4,macd_macdSMA_trigger4,PRICE_CLOSE,MODE_SIGNAL,shift);
         if ((d < mm[shift] && d > 0) || (d < 0 && d > mm[shift])) 
         {
            cross[shift] = d;
         }
         break;
         case 5:
         d=iMomentum(NULL,0,momentumPeriod_trigger5,PRICE_CLOSE,shift)-100;
         IndicatorShortName("Bollinger Squeeze with Momentum ("+momentumPeriod_trigger5+",CLOSE)");
         break;
         case 6:
         d=iWPR(NULL,0,williamsPR_trigger6,shift)+50;
         IndicatorShortName("Bollinger Squeeze with Williams% ("+williamsPR_trigger6+")");
         break;
         case 7:
         d=iADX(NULL,0,adx_trigger7,PRICE_CLOSE,MODE_MAIN,shift);
         IndicatorShortName("Bollinger Squeeze with ADX ("+adx_trigger7+")");
         break;
         case 8:
         d=iDeMarker(NULL,0,demarker_trigger8,shift)-0.5;
         IndicatorShortName("Bollinger Squeeze with Demarker ("+demarker_trigger8+")");
         break;
      }
      
      
      if (showLine) histoLine[shift]=d;
      
      if(d>0) 
      {
         upB[shift]=d;
      } 
      else if (d<0)
      {
         loB[shift]=d;
      }
      
      diff = iATR(NULL,0,keltPrd,shift)*keltFactor;
      std = iStdDev(NULL,0,bolPrd,MODE_SMA,0,PRICE_CLOSE,shift);
      bbs = bolDev * std / diff;

      if(bbs<1) {

         if (d > 0) {
            upB2[shift]=d;
            upB[shift]=0;
            loB[shift]=0;
            loB2[shift]=0;
         } else {
            loB2[shift]=d;
            loB[shift]=0;
            upB[shift]=0;
            upB2[shift]=0;
         }
         
      } else {

         if (d > 0) {
            upB[shift]=d;
            upB2[shift]=0;
            loB[shift]=0;
            loB2[shift]=0;
         } else {
            loB[shift]=d;
            loB2[shift]=0;
            upB[shift]=0;
            upB2[shift]=0;
         }
      }
      
      shift--;
      
   }
   
   return(0);

}

